==> activity-center-api-3.5.18-p1-20220616.054718-3-sources.jar: cn/com/duiba/activity/center/api/dto/tlcb/TaskRecordDto.java <==
package cn.com.duiba.activity.center.api.dto.tlcb;

import java.io.Serializable;
import java.util.Date;

/**
* 泰隆银行任务组件-任务完成记录表
*/
public class TaskRecordDto implements Serializable {

    private static final long serialVersionUID = -3150508889244675381L;
    /**
    * 自增主键
    */
    private Long id;

    /**
    * appId
    */
    private Long appId;

    /**
    * 活动id
    */
    private Long actId;

    /**
    * 用户id
    */
    private Long consumerId;

    /**
    * 任务id
    */
    private Long taskId;

    /**
    * 任务状态：0-未完成，1-已完成/待领取，2-已领取
    */
    private Integer taskStatus;

    /**
    * 奖励类型，积分：1，奖品：2，链接：3
    */
    private Integer awardType;

    /**
     * 奖品id
     */
    private Long appItemId;

    /**
     * 商品类型
     */
    private String appItemType;

    /**
    * 领取异常原因
    */
    private String errorMsg;

    /**
    * 保底积分
    */
    private Integer guaranteedCredits;

    /**
    * 主订单号
    */
    private String orderNum;

    /**
     * 活动订单号
     */
    private String activityOrderNum;

    /**
     * 奖品扩展信息
     */
    private String extraInfo;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getActId() {
        return actId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }

    public Long getTaskId() {
        return taskId;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }

    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setAwardType(Integer awardType) {
        this.awardType = awardType;
    }

    public Integer getAwardType() {
        return awardType;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getAppItemType() {
        return appItemType;
    }

    public void setAppItemType(String appItemType) {
        this.appItemType = appItemType;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setGuaranteedCredits(Integer guaranteedCredits) {
        this.guaranteedCredits = guaranteedCredits;
    }

    public Integer getGuaranteedCredits() {
        return guaranteedCredits;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public String getActivityOrderNum() {
        return activityOrderNum;
    }

    public void setActivityOrderNum(String activityOrderNum) {
        this.activityOrderNum = activityOrderNum;
    }

    public String getExtraInfo() {
        return extraInfo;
    }

    public void setExtraInfo(String extraInfo) {
        this.extraInfo = extraInfo;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> activity-center-api-3.6.11-20250109.122334-10-sources.jar: cn/com/duiba/activity/center/api/dto/tlcb/TaskRecordDto.java <==
package cn.com.duiba.activity.center.api.dto.tlcb;

import java.io.Serializable;
import java.util.Date;

/**
* 泰隆银行任务组件-任务完成记录表
*/
public class TaskRecordDto implements Serializable {

    private static final long serialVersionUID = -3150508889244675381L;
    /**
    * 自增主键
    */
    private Long id;

    /**
    * appId
    */
    private Long appId;

    /**
    * 活动id
    */
    private Long actId;

    /**
     * 活动长id
     */
    private Long operatingActivityId;

    /**
    * 用户id
    */
    private Long consumerId;

    /**
    * 任务id
    */
    private Long taskId;

    /**
    * 任务状态：0-未完成，1-已完成/待领取，2-已领取
    */
    private Integer taskStatus;

    /**
    * 奖励类型，积分：1，奖品：2，链接：3
    */
    private Integer awardType;

    /**
     * 奖品id
     */
    private Long appItemId;

    /**
     * 商品类型
     */
    private String appItemType;

    /**
    * 领取异常原因
    */
    private String errorMsg;

    /**
    * 保底积分
    */
    private Integer guaranteedCredits;

    /**
    * 主订单号
    */
    private String orderNum;

    /**
     * 活动订单号
     */
    private String activityOrderNum;

    /**
     * 奖品扩展信息
     */
    private String extraInfo;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getActId() {
        return actId;
    }

    public Long getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(Long operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }

    public Long getTaskId() {
        return taskId;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }

    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setAwardType(Integer awardType) {
        this.awardType = awardType;
    }

    public Integer getAwardType() {
        return awardType;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getAppItemType() {
        return appItemType;
    }

    public void setAppItemType(String appItemType) {
        this.appItemType = appItemType;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setGuaranteedCredits(Integer guaranteedCredits) {
        this.guaranteedCredits = guaranteedCredits;
    }

    public Integer getGuaranteedCredits() {
        return guaranteedCredits;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public String getActivityOrderNum() {
        return activityOrderNum;
    }

    public void setActivityOrderNum(String activityOrderNum) {
        this.activityOrderNum = activityOrderNum;
    }

    public String getExtraInfo() {
        return extraInfo;
    }

    public void setExtraInfo(String extraInfo) {
        this.extraInfo = extraInfo;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}
